@@ -1,5 +1,11 @@
 #!/usr/bin/env python
 
+# I recommend that you don't put this as your post-commit hook, rather you
+# write a short shell script to call it, which has set PYTHONPATH as it
+# should, so that you don't have to edit parts of a package and have it
+# overwritten all the time.
+
+from os import path
 import sys
 import subprocess
 import socket
@@ -27,6 +33,7 @@ write = Writer(conf.ipc_socket)
 
 # {{{ Get SVN info
 repos, rev = sys.argv[1:]
+repos_name = path.basename(repos)
 author = run(("/usr/bin/svnlook", "author", "--revision", rev, repos)).split("\n", 1)[0]
 log = run(("/usr/bin/svnlook", "log", "--revision", rev, repos)).rstrip()
 changed = run(("/usr/bin/svnlook", "changed", "--revision", rev, repos)).rstrip().split("\n")
@@ -34,17 +41,15 @@ changed_dirs = run(("/usr/bin/svnlook", "dirs-changed", "--revision", rev, repos
 # }}}
 
 # {{{ Write out stuff
-# Yeah, ugly, so sue me.
-write("%s: %s commits r%s. %d file%s in %d dir%s changed." % (repos, author, rev, len(changed), "s"[len(changed) == 1:], len(changed_dirs), "s"[len(changed_dirs) == 1:]))
+write("%s: %s commits r%s. %d file%s in %d dir%s changed." % (repos_name,
+    author, rev, len(changed), "s"[len(changed) == 1:], len(changed_dirs),
+    "s"[len(changed_dirs) == 1:]))
 
 if len(changed) <= 5:
     for change in changed:
         write("  * %s" % change)
 
-log = log.split("\n")
 while log:
-    line = log.pop(0)
-    while line:
-        write(line[:80])
-        line = line[80:]
+    write(log[:80])
+    log = log[80:]
 # }}}
